import React, { ReactElement, ReactNode } from 'react';
import { SVGProps } from 'react';

// Define Sizes and IconProps types
export type Sizes = 12 | 14 | 16 | 20 | 24 | 28 | 32 | 40;
export type IconProps = SVGProps<SVGSVGElement> & {
  component: ReactNode | ReactElement<any>;
  size?: Sizes;
  color?: string;
};

// Icon component definition
export const Icon: React.FC<IconProps> = ({ component, size = 24, color, ...props }) => {
  if (!component) {
    console.error('No icon found');
    return <div></div>;
  }

  const style = { fontSize: size, color };

  // Check if component is a valid React element
  if (React.isValidElement(component)) {
    return React.cloneElement(component as ReactElement<any>, {
      style: { ...style, ...(component as ReactElement<any>).props.style },
      width: size,
      height: size,
      ...props,
    });
  }

  // Check if component is a function (assume it's a custom SVG component)
  if (typeof component === 'function') {
    // Render the custom SVG component directly
    return (
      <svg xmlns="http://www.w3.org/2000/svg" width={size} height={size} viewBox="0 0 32 32" style={style} {...props}>
        {(component as () => ReactNode)()}
      </svg>
    );
  }

  // Default case: render null or fallback
  console.error('Unsupported icon type');
  return null;
};
